Function git_features::hash::crc32 [−][src]
Compute a CRC32 value of the given input bytes.
In case multiple chunkes of bytes are present, one should use crc32_update() instead.
Compute a CRC32 value of the given input bytes.
In case multiple chunkes of bytes are present, one should use crc32_update() instead.